@@ -10,10 +10,10 @@ Copyright © Semantyk 2020. All rights reserved.\
 –––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––
 '''
 
-__author__ = 'Daniel Bakas Amuchastegui'
+__author__ = 'Semantyk'
 __date__ = '2017-08-31'
-__email__ = 'daniel@semantyk.com'
-__version__ = '0.0.0.67'
+__email__ = 'contact@semantyk.com'
+__version__ = '0.0.0.68'
 
 from . import archive, av_reality, core, das, dots, dvm, games, learn, sam, store, tools, uuid_generator
 from .archive import *
